couchdb.schema.IntegerField

Package couchdb :: Module schema :: Class IntegerField |

# Class IntegerField

    object --+
             |
         Field --+
                 |
                IntegerField

Schema field for integer values.

Instance Methods
Inherited from `Field`: `__get__`, `__init__`, `__set__` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties
Inherited from `object`: `__class__`